@@ -13,6 +13,7 @@ BETWEEN
 BY
 CASE
 CAST
+CLONE
 COLLATE
 CONTAINS
 CREATE
@@ -71,6 +72,7 @@ OVER
 PARTITION
 PIVOT
 PRECEDING
+PRIMARY
 PROTO
 RANGE
 RECURSIVE
@@ -100,28 +102,39 @@ WITHIN"""
 
 # Note BigQuery doesn't have a list of Unreserved Keywords
 # so these are just ones we need to allow parsing to work
-bigquery_unreserved_keywords = """ACCOUNT
+bigquery_unreserved_keywords = """ACCESS
+ACCOUNT
 ADD
 ADMIN
 AFTER
 ALTER
 APPLY
+ASSIGNMENT
+ASSERT
 AUTO_INCREMENT
 BEGIN
 BERNOULLI
+BI_CAPACITY
 BINARY
 BINDING
+BREAK
 CACHE
+CALL
+CAPACITY
 CASCADE
 CHAIN
 CHARACTER
 CHECK
+CLONE
 CLUSTER
 COLUMN
+COLUMNS
 COMMENT
 COMMIT
 CONCURRENTLY
+CONTINUE
 CONNECT
+CONNECTION
 CONSTRAINT
 COPY
 CURRENT_USER
@@ -134,12 +147,18 @@ DECLARE
 DELETE
 DESCRIBE
 DETERMINISTIC
+DO
 DOMAIN
 DOUBLE
 DROP
+ELSEIF
+ENFORCED
+ERROR
+EXCEPTION
 EXECUTE
 EXECUTION
 EXPLAIN
+EXPORT
 EXTENSION
 EXTERNAL
 FILE
@@ -147,6 +166,7 @@ FILTER
 FIRST
 FOREIGN
 FORMAT
+FRIDAY
 FUNCTION
 FUTURE
 GRANT
@@ -154,27 +174,42 @@ GRANTED
 GRANTS
 HOUR
 ILIKE
+IMMEDIATE
 IMPORTED
+IN
 INCREMENT
 INDEX
+INOUT
 INSERT
 INTEGRATION
 KEY
+ITERATE
 LANGUAGE
 LARGE
 LAST
+LEAVE
+LOOP
 MANAGE
 MASKING
+MATCHED
 MATERIALIZED
+MAX
 MAXVALUE
+MESSAGE
+MIN
 MINUS
 MINVALUE
 ML
 MODEL
 MODIFY
+MONDAY
 MONITOR
 NAME
 NAN
+NFC
+NFKC
+NFD
+NFKD
 NOCACHE
 NOCYCLE
 NOORDER
@@ -184,6 +219,8 @@ OPERATE
 OPTION
 OPTIONS
 ORDINAL
+ORGANIZATION
+OUT
 OVERLAPS
 OVERWRITE
 OWNERSHIP
@@ -195,17 +232,23 @@ PRIMARY
 PRIOR
 PRIVILEGES
 PROCEDURE
+PROJECT
 PUBLIC
 QUALIFY
 QUARTER
+RAISE
 READ
 REFERENCE_USAGE
 REFERENCES
 RENAME
+REPEAT
 REPEATABLE
 REPLACE
+REPLICA
+RESERVATION
 RESOURCE
 RESTRICT
+RETURN
 RETURNS
 REVOKE
 RLIKE
@@ -213,33 +256,45 @@ ROLE
 ROLLBACK
 ROW
 ROUTINE
+SAFE
+SATURDAY
 SCHEMA
 SCHEMAS
+SEARCH
 SECOND
 SEPARATOR
 SERVER
 SEQUENCE
 SESSION_USER
+SETS
 SHARE
+SNAPSHOT
+SOURCE
 STAGE
 START
 STREAM
+SUNDAY
 SYSTEM
 SYSTEM_TIME
 TABLE
 TABLESPACE
+TARGET
 TASK
 TEMP
 TEMPORARY
+THURSDAY
 TIME
 TIMESTAMP
 TRANSACTION
 TRANSIENT
 TRIGGER
 TRUNCATE
+TUESDAY
 TYPE
+UNDROP
 UNIQUE
 UNSIGNED
+UNTIL
 UPDATE
 USAGE
 USE
@@ -248,9 +303,13 @@ USER
 VALUE
 VALUES
 VARYING
+VECTOR
 VERSION
 VIEW
 WAREHOUSE
+WEDNESDAY
+WEEK
+WHILE
 WITHOUT
 WORK
 WRAPPER
