@@ -8,6 +8,7 @@ ALTER
 AND
 ANY
 AS
+ASOF
 BETWEEN
 BY
 CAST
@@ -20,10 +21,9 @@ CURRENT
 CURRENT_DATE
 CURRENT_TIME
 CURRENT_TIMESTAMP
-CURRENT_USER
 DELETE
+DECLARE
 DISTINCT
-DO
 DROP
 ELSE
 EXISTS
@@ -50,11 +50,11 @@ LEFT
 LIKE
 LOCALTIME
 LOCALTIMESTAMP
+MATCH_CONDITION
 MATCH_RECOGNIZE
 MINUS
 NATURAL
 NOT
-NOTIFY
 NULL
 NULL_IF
 OF
@@ -82,8 +82,8 @@ TRIGGER
 TRY_CAST
 UNION
 UNIQUE
-UPDATE
 UNPIVOT
+UPDATE
 USING
 VALUES
 WHEN
@@ -92,18 +92,24 @@ WHERE
 WITH
 """
 
-snowflake_unreserved_keywords = """ABORT
+snowflake_unreserved_keywords = """
+ABORT
 ABORT_STATEMENT
 ACCESS
 ACCOUNT
 ACCOUNTS
+ACTION
 ADD
 ADMIN
 AFTER
-ALLOWED_IP_LIST
-ALLOWED_VALUES
+AGGREGATE
 ALLOW_DUPLICATE
 ALLOW_OVERLAPPING_EXECUTION
+ALLOW_WRITES
+ALLOWED_IP_LIST
+ALLOWED_NETWORK_RULE_LIST
+ALLOWED_VALUES
+ALWAYS
 API
 API_INTEGRATION
 APPEND_ONLY
@@ -115,13 +121,13 @@ ATTACH
 AUTHORIZATION
 AUTHORIZATIONS
 AUTO
-AUTOINCREMENT
 AUTO_COMPRESS
 AUTO_INCREMENT
 AUTO_INGEST
 AUTO_REFRESH
 AUTO_RESUME
 AUTO_SUSPEND
+AUTOINCREMENT
 AVRO
 AWS_KEY_ID
 AWS_ROLE
@@ -148,6 +154,7 @@ BINARY_FORMAT
 BINDING
 BLOCK
 BLOCKED_IP_LIST
+BLOCKED_NETWORK_RULE_LIST
 BODY
 BROTLI
 BZ2
@@ -157,12 +164,12 @@ CALLED
 CALLER
 CASCADE
 CASE
-CASES
 CASE_INSENSITIVE
 CASE_SENSITIVE
+CASES
 CHAIN
-CHANGES
 CHANGE_TRACKING
+CHANGES
 CHARACTER
 CLONE
 CLUSTER
@@ -195,19 +202,21 @@ CURRENT_SCHEMAS
 CURRENT_SESSION
 CURRENT_STATEMENT
 CURRENT_TRANSACTION
+CURRENT_USER
 CURRENT_VERSION
 CURRENT_WAREHOUSE
 CURSOR
 CYCLE
+DAILY
 DATA
-DATABASE
-DATABASES
 DATA_FORMAT
 DATA_RETENTION_TIME_IN_DAYS
+DATABASE
+DATABASES
 DATE
 DATE_FORMAT
-DAILY
 DAYS_TO_EXPIRY
+DEBUG
 DEFAULT
 DEFAULT_DDL_COLLATION
 DEFAULT_NAMESPACE
@@ -225,31 +234,37 @@ DETAILED_OUTPUT
 DIRECTION
 DIRECTORY
 DISABLE
-DISABLED
 DISABLE_AUTO_CONVERT
 DISABLE_SNOWFLAKE_DATA
+DISABLED
 DISPLAY_NAME
+DO
 DOMAIN
 DOUBLE
+DOWNSTREAM
+DYNAMIC
 ECONOMY
 EMAIL
 EMPTY
 EMPTY_FIELD_AS_NULL
 ENABLE
-ENABLED
 ENABLE_OCTAL
+ENABLED
 ENCODING
 ENCRYPTION
 END
 END_TIMESTAMP
-ENFORCED
 ENFORCE_LENGTH
+ENFORCED
 ENUM
+ERROR
 ERROR_INTEGRATION
 ERROR_ON_COLUMN_COUNT_MISMATCH
 ESCAPE
 ESCAPE_UNENCLOSED_FIELD
+EVENT
 EXCEPT
+EXCEPTION
 EXCHANGE
 EXCLUDE
 EXECUTE
@@ -257,14 +272,17 @@ EXECUTION
 EXPLAIN
 EXTENSION
 EXTERNAL
+EXTERNAL_ACCESS_INTEGRATIONS
 EXTERNAL_STAGE
+FATAL
 FETCH
 FIELD_DELIMITER
+FIELD_OPTIONALITY_ENCLOSED_BY
 FIELD_OPTIONALLY_ENCLOSED_BY
 FILE
-FILES
 FILE_EXTENSION
 FILE_FORMAT
+FILES
 FILTER
 FINAL
 FIRST
@@ -273,8 +291,8 @@ FOR
 FORCE
 FOREIGN
 FORMAT
-FORMATS
 FORMAT_NAME
+FORMATS
 FREQUENCY
 FUNCTION
 FUNCTIONS
@@ -303,11 +321,15 @@ IMMEDIATE
 IMMEDIATELY
 IMMUTABLE
 IMPORT
-IMPORTS
 IMPORTED
+IMPORTS
+INCLUDE
+INCLUDE_METADATA
 INCLUDE_QUERY_ID
 INDEX
+INFO
 INFORMATION
+INITIALIZE
 INITIALLY
 INITIALLY_SUSPENDED
 INPUT
@@ -333,33 +355,40 @@ LISTING
 LOCAL
 LOCATION
 LOCKS
+LOG_LEVEL
 LOGIN_NAME
 LS
 LZO
 M
+MAIN_FILE
 MANAGE
 MANAGED
 MASKING
 MASTER_KEY
 MATCH
+MATCH_BY_COLUMN_NAME
 MATCHED
 MATCHES
-MATCH_BY_COLUMN_NAME
 MATERIALIZED
-MAXVALUE
 MAX_BATCH_ROWS
 MAX_CLUSTER_COUNT
 MAX_CONCURRENCY_LEVEL
 MAX_DATA_EXTENSION_TIME_IN_DAYS
 MAX_FILE_SIZE
 MAX_SIZE
+MAXVALUE
 MEASURES
 MERGE
+METADATA$FILENAME
+METADATA$FILE_ROW_NUMBER
+METADATA$FILE_CONTENT_KEY
+METADATA$FILE_LAST_MODIFIED
+METADATA$START_SCAN_TIME
 MIDDLE_NAME
+MIN_CLUSTER_COUNT
 MINS_TO_BYPASS_MFA
 MINS_TO_UNLOCK
 MINVALUE
-MIN_CLUSTER_COUNT
 ML
 MODEL
 MODIFIED_AFTER
@@ -370,27 +399,32 @@ MUST_CHANGE_PASSWORD
 NAME
 NAN
 NETWORK
+NEVER
 NEXT
 NEXTVAL
-NEVER
 NO
 NOCACHE
 NOCYCLE
 NONE
 NOORDER
+NORELY
 NOTIFICATION
 NOTIFICATION_INTEGRATION
 NOTIFICATION_PROVIDER
+NOTIFY
 NOTIFY_USERS
-NULLS
+NOVALIDATE
 NULL_IF
+NULLS
 OBJECT
 OBJECTS
+OFF
 OFFSET
 OMIT
+ON_ERROR
+ON_EVENT
 ONE
 ONLY
-ON_ERROR
 OPERATE
 OPTIMIZATION
 OPTION
@@ -409,17 +443,30 @@ PACKAGES
 PARALLEL
 PARAMETERS
 PARQUET
+PARSE_HEADER
+PARTIAL
 PARTITION
+PARTITION_TYPE
 PASSWORD
+PASSWORD_HISTORY
+PASSWORD_LOCKOUT_TIME_MINS
+PASSWORD_MAX_AGE_DAYS
+PASSWORD_MAX_LENGTH
+PASSWORD_MAX_RETRIES
+PASSWORD_MIN_AGE_DAYS
+PASSWORD_MIN_LOWER_CASE_CHARS
+PASSWORD_MIN_LENGTH
+PASSWORD_MIN_NUMERIC_CHARS
+PASSWORD_MIN_SPECIAL_CHARS
+PASSWORD_MIN_UPPER_CASE_CHARS
 PAST
 PATTERN
-FIELD_OPTIONALITY_ENCLOSED_BY
 PER
 PERCENT
 PERMUTE
 PIPE
-PIPES
 PIPE_EXECUTION_PAUSED
+PIPES
 PIVOT
 POLICIES
 POLICY
@@ -437,6 +484,7 @@ PURGE
 PUT
 PYTHON
 QUERIES
+QUERY_WAREHOUSE
 QUEUE
 RANGE
 RAW_DEFLATE
@@ -444,11 +492,13 @@ READ
 RECLUSTER
 RECORD_DELIMITER
 RECURSIVE
-REFERENCES
 REFERENCE_USAGE
+REFERENCES
 REFRESH
+REFRESH_MODE
 REFRESH_ON_CREATE
 REGIONS
+RELY
 REMOVE
 RENAME
 REPEATABLE
@@ -467,15 +517,16 @@ RESULT
 RESULTSET
 RESUME
 RETURN
-RETURNS
 RETURN_ALL_ERRORS
 RETURN_ERRORS
 RETURN_FAILED_ONLY
+RETURNS
 RM
 ROLE
 ROLES
 ROLLBACK
 ROLLUP
+ROOT_LOCATION
 ROUTINE
 ROUTINES
 ROW
@@ -491,6 +542,7 @@ SCHEMA
 SCHEMAS
 SEARCH
 SECONDARY
+SECRETS
 SECURE
 SECURITY
 SEED
@@ -502,10 +554,11 @@ SESSION
 SESSION_USER
 SETS
 SHARE
-SHARES
 SHARE_RESTRICTIONS
+SHARES
 SHOW
 SHOW_INITIAL_ROWS
+SIMPLE
 SINGLE
 SIZE_LIMIT
 SKIP
@@ -520,23 +573,29 @@ SNOWFLAKE_SSE
 SOURCE_COMPRESSION
 SQL
 STAGE
-STAGES
 STAGE_COPY_OPTIONS
 STAGE_FILE_FORMAT
+STAGES
 STANDARD
-STARTS
 START_TIMESTAMP
+STARTS
 STATEMENT
 STATEMENT_QUEUED_TIMEOUT_IN_SECONDS
 STATEMENT_TIMEOUT_IN_SECONDS
 STORAGE
 STORAGE_ALLOWED_LOCATIONS
+STORAGE_AWS_EXTERNAL_ID
 STORAGE_AWS_OBJECT_ACL
 STORAGE_AWS_ROLE_ARN
+STORAGE_BASE_URL
 STORAGE_BLOCKED_LOCATIONS
 STORAGE_INTEGRATION
+STORAGE_LOCATION
+STORAGE_LOCATIONS
 STORAGE_PROVIDER
 STREAM
+STREAMLIT
+STREAMLITS
 STREAMS
 STRIP_NULL_VALUES
 STRIP_OUTER_ARRAY
@@ -553,6 +612,7 @@ TABLES
 TABLESPACE
 TABULAR
 TAG
+TARGET_LAG
 TARGET_PATH
 TASK
 TASKS
@@ -562,15 +622,17 @@ TEMPORARY
 TERSE
 TEXT
 TIME
+TIME_FORMAT
 TIMESTAMP
 TIMESTAMP_FORMAT
-TIME_FORMAT
 TOP
+TRACE
+TRACE_LEVEL
 TRANSACTION
 TRANSACTIONS
 TRANSIENT
-TRIM_SPACE
 TRIGGERS
+TRIM_SPACE
 TRUNCATE
 TRUNCATECOLUMNS
 TYPE
@@ -583,12 +645,14 @@ URL
 US
 USAGE
 USE
+USE_ANY_ROLE
 USER
-USERS
+USER_SPECIFIED
 USER_TASK_MANAGED_INITIAL_WAREHOUSE_SIZE
 USER_TASK_TIMEOUT_MS
-USE_ANY_ROLE
+USERS
 UTF8
+VALIDATE
 VALIDATE_UTF8
 VALIDATION_MODE
 VALUE
@@ -599,11 +663,14 @@ VERSION
 VIEW
 VIEWS
 VOLATILE
+VOLUME
+VOLUMES
 WAIT_FOR_COMPLETION
 WAREHOUSE
-WAREHOUSES
 WAREHOUSE_SIZE
 WAREHOUSE_TYPE
+WAREHOUSES
+WARN
 WEEKLY
 WINDOW
 WITH
