@@ -22,6 +22,11 @@ WITH TAG (foo = 'bar', hello = 'world')
 COPY GRANTS
 AS SELECT col1, col2 FROM src_table;
 
+CREATE OR REPLACE VIEW view_with_tags_and_copy_grants
+WITH TAG (foo = "bar", hello = "world")
+COPY GRANTS
+AS SELECT col1, col2 FROM src_table;
+
 CREATE OR REPLACE VIEW view_with_column_comment
 (
     col1,
@@ -50,3 +55,48 @@ CREATE OR REPLACE VIEW vw_appt_latest AS (
       )
   SELECT * from most_current
 );
+
+CREATE OR REPLACE VIEW IF NOT EXISTS view_with_rls
+(
+    COL1,
+    COL2
+) WITH ROW ACCESS POLICY my_db.my_schema.my_policy ON (COL1) AS (
+  SELECT
+    COL1,
+    COL2
+  FROM my_table
+);
+
+
+CREATE OR REPLACE VIEW IF NOT EXISTS view_with_rls
+(
+    COL1 WITH MASKING POLICY my_db.my_schema.my_policy,
+    COL2
+) WITH ROW ACCESS POLICY my_db.my_schema.my_policy ON (COL1) AS (
+  SELECT
+    COL1,
+    COL2
+  FROM my_table
+);
+
+CREATE OR REPLACE MATERIALIZED VIEW IF NOT EXISTS view_with_rls
+(
+    COL1,
+    COL2
+) WITH ROW ACCESS POLICY my_db.my_schema.my_policy ON (COL1) AS (
+  SELECT
+    COL1,
+    COL2
+  FROM my_table
+);
+
+CREATE OR REPLACE VIEW IF NOT EXISTS view_with_column_tags
+(
+    COL1 WITH TAG (my_db.my_schema.my_policy='MY_TAG'),
+    COL2
+) AS (
+  SELECT
+    COL1,
+    COL2
+  FROM my_table
+);
